from pydantic import BaseModel, Field
from typing import List, Optional, Dict, Any
from datetime import datetime


class MarketBase(BaseModel):
    exchange_id: str
    rank: Optional[str] = None
    base_symbol: str
    base_id: str
    quote_symbol: str
    quote_id: str
    price_quote: str
    price_usd: str
    volume_usd_24hr: str
    percent_exchange_volume: str
    trades_count_24hr: Optional[str] = None
    updated: int


class MarketCreate(MarketBase):
    pass


class MarketInDB(MarketBase):
    id: int
    last_updated: datetime

    class Config:
        orm_mode = True


class MarketsResponse(BaseModel):
    data: List[MarketBase]
    timestamp: int


class ErrorResponse(BaseModel):
    error: str
    timestamp: Optional[int] = None